Search.setIndex({docnames:["index"],envversion:{"sphinx.domains.c":2,"sphinx.domains.changeset":1,"sphinx.domains.citation":1,"sphinx.domains.cpp":4,"sphinx.domains.index":1,"sphinx.domains.javascript":2,"sphinx.domains.math":2,"sphinx.domains.python":3,"sphinx.domains.rst":2,"sphinx.domains.std":2,sphinx:56},filenames:["index.rst"],objects:{"":{AIRPrediction:[0,0,0,"-"],ARIMA_model:[0,0,0,"-"],prophet_model:[0,0,0,"-"],sampleapp:[0,0,0,"-"]},AIRPrediction:{arima:[0,1,1,""],compare_models:[0,1,1,""],prophet:[0,1,1,""],validate_input:[0,1,1,""]},ARIMA_model:{arima_prediction:[0,1,1,""]},prophet_model:{prophet_prediction:[0,1,1,""]},sampleapp:{MainWindow:[0,2,1,""],main:[0,1,1,""]}},objnames:{"0":["py","module","Python module"],"1":["py","function","Python function"],"2":["py","class","Python class"]},objtypes:{"0":"py:module","1":"py:function","2":"py:class"},terms:{"boolean":0,"class":0,"function":0,"import":0,"return":0,A:0,The:0,To:0,about:0,abov:0,accept:0,advanc:0,airpredict:0,all:0,allow:0,america:0,ani:0,app:0,applic:0,ar:0,arima:0,arima_model:0,arima_predict:0,author:0,avoid:0,befor:0,both:0,calendar:0,call:0,casto:0,citi:0,cnaehr:0,co:0,colin:0,compar:0,compare_model:0,comparison:0,contain:0,counti:0,creat:0,csv:0,daniel:0,danielcasto:0,data:0,dataset:0,date:0,dd:0,demonstr:0,derek:0,determin:0,driver:0,each:0,edu:0,element:0,error:0,file:0,format:0,framework:0,from:0,gener:0,given:0,haotian:0,haotianwang:0,hold:0,host:0,includ:0,index:0,input:0,learn:0,list:0,locat:0,machin:0,made:0,main:0,mainwindow:0,make:0,messag:0,mm:0,model:0,modul:0,multipl:0,naehr:0,no2:0,none:0,note:0,o3:0,open:0,order:0,other:0,output:0,page:0,param:0,paramet:0,parent:0,part:0,pena:0,pollut:0,pollution_us_2000_2016:0,ppb:0,predict:0,prepar:0,produc:0,prophet:0,prophet_model:0,prophet_predict:0,provid:0,py:0,python:0,qwidget:0,rewrit:0,run:0,sampl:0,sampleapp:0,search:0,seri:0,so2:0,specifi:0,speed:0,state:0,statement:0,string:0,success:0,taken:0,them:0,time:0,time_series_model:0,two:0,ufl:0,ui:0,unit:0,us:0,user:0,util:0,valid:0,validate_input:0,valu:0,wa:0,wang:0,well:0,where:0,window:0,yyyi:0},titles:["Welcome to Air Quality\u2019s documentation!"],titleterms:{air:0,document:0,indic:0,qualiti:0,s:0,tabl:0,welcom:0}})